/* CoolTran, traductor de trminos.
 * 
 * Copyright (C) 2007
 *
 * Authors: Javier Garca Palacios <jgarcia1709@gmail.com>
 *          Diego Sevillano de Miguel <sevas85@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 */


import java.awt.Color;


public class Aplicacion {

	
	Configuracion config = null;
	Ventana controlador = null;
	Splash splashInicio =null;
	Usuario UserRegis = null;
	Valoracion valora = null;
	Busqueda busqueda = null;
	Conexion conexion = null;
	Version version = null;
	BaseDatosRemota baseVersion = null;
	PortaPapeles clipboard;				
	IconoTray tray=null;
	PestanaBusqueda p1 = null;
	PestanaDiccionarios p2 = null;
	PestanaConfig p3 = null;
	PestanaWiki p4 = null;
	PestanaWikiAnadir p4a = null;
	PestanaWikiRegistro p4r = null;
	
	public Aplicacion (){ 
		
		//Creo la Configuracion
		
		config =new Configuracion();	
		
		//Se crea y pinta la ventana
		
		controlador = new Ventana(); 		
		
		//Creamos el Splash
		
		getSplash();
		
		//Se aplica la configuracin a la ventana (Desplegables etc..)
		
		config.aplicarConfiguracion(controlador);	
		
		//Defenimos variables
		
		setVariables();
		
		//Se lanza en control de eventos sobre la ventana
		
		eventos();	
		
		//Creamos la Conexion

		getConexion();
		
		//Elimino el splash al cargar la ventana
						
		configurarVentana();
			
		//Creo el Tray
		
		creaTray();
		
		//Compruebo nuevas bases de datos
		
		comprobarBaseDatosRemota();
		
	}//Aplicacion
	
	/**********************************************************************************/
	/**                      METODOS INICIALIZACION								     **/
	/**********************************************************************************/	
	
	private void configurarVentana() {
		
		if( Boolean.parseBoolean(Configuracion.propiedades.getProperty("splash"))){
			splashInicio.setVisible(false);
			controlador.setVisible(true);
		}
		controlador.panelInicial.panelPestanas.pestana1.campoTextoBusqueda.requestFocusInWindow();	
	}//configurarVentana

	private void setVariables(){
		
	//Defenimos variables para refereniar mas corto	
		
		 p1 =controlador.panelInicial.panelPestanas.pestana1;
		 p2 =controlador.panelInicial.panelPestanas.pestana2;
		 p3 =controlador.panelInicial.panelPestanas.pestana3;
		 p4 =controlador.panelInicial.panelPestanas.pestana4;
		 p4a =controlador.panelInicial.panelPestanas.pestana4.panelAnadir;
		 p4r =controlador.panelInicial.panelPestanas.pestana4.panelRegistrar;

	 
	}//setVariables
	
	private void eventos(){
		
	    p1.configurarEventosPestana(config, this);
	    p2.configurarEventosPestana(config, p1, this, controlador);
	    p3.configurarEventosPestana(config, this);
	    p4a.configurarEventosPestana( this,p4);
	    p4r.configurarEventosPestana(controlador, this);
	    controlador.configurarEventosVentana(this);	   
		
	}//eventos
	
	private void getConexion() {
		
		
		conexion = new Conexion();
		
		if (Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion"))==true){
			p1.etiquetaMensaje.setText(Configuracion.messages.getString("msj_conectando"));								
			try{
			// se crea la conexin con la base de datos
				
				conexion.conectar();
				if (conexion.isConectado()){

					//creamos los colaborativos
					config.cargarColaborativo(conexion);
					UserRegis = config.aplicarConfiguracionColaborativo(controlador, conexion);
						
					//Comprobamos la  version de nuestro sistema 				
					version = new Version(Configuracion.propiedades.getProperty("SO"),conexion);
					if(version.comprobarVersion()){					
						p1.etiquetaMensaje.setText("Nueva Versin "+version.getNombre());					
					}
				}
			 }catch(Exception conexion){
		    	p1.etiquetaMensaje.setText(Configuracion.messages.getString("msj_errorconexion"));
				if(Boolean.parseBoolean(Configuracion.propiedades.getProperty("splash"))){
					splashInicio.setVisible(false);
						controlador.setVisible(true);
				}
				p1.campoTextoBusqueda.requestFocusInWindow();
		     }
		}
	}//getConexion

	private void getSplash(){
		
		if(Boolean.parseBoolean(Configuracion.propiedades.getProperty("splash"))){
			splashInicio = new Splash("imagenes/splash.png",controlador,15000); 	
		}else{
					controlador.setVisible(true);
		}
	}//getSplash
	
	private void comprobarBaseDatosRemota() {
		if (conexion.isConectado()){
				baseVersion = new BaseDatosRemota(conexion);
				if (baseVersion.comprobarBaseDatos()){
					
					config.cambiaBaseDatos(baseVersion.getFecha(),
												  baseVersion.getUsuario(),
												  baseVersion.getPassword(),
												  baseVersion.getUrl());
					p1.etiquetaMensaje.setText("Nueva Base de Datos, Reinicie");		
					
				}
		}
	
	}
	
	
	/**********************************************************************************/
	/**                      METODOS RELACIONADOS CON EVENTOS					     **/
	/**********************************************************************************/
	
	
	public void creaTray( ){
			
		if (Configuracion.propiedades.getProperty("SO").toLowerCase().contains("windows")){
				if (tray != null){
					tray.tray.removeTrayIcon(tray.ti);
				}
		
		tray = new IconoTray(this);			//se crea el tray icon
		tray.setTipoDicTray("Local"); 	//por defecto se selecciona el diccionario Local
		tray.setDiccLocalesTray(config.arrayCadDiccInstall.length, config.arrayCadDiccInstall ,Configuracion.propiedades.getProperty("dicLocDefault"));
		if (Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion"))==true){
			if (conexion.isConectado()){
				if ((Configuracion.propiedades.getProperty("tipoDic")).equals("Colaborativo")){
					tray.setTipoDicTray("Colaborativo"); //si se cumple todo lo anterior
				}
				tray.setDiccColaborativosTray(config.arrayWikiInstall.size(),  config.arrayWikiInstall ,Integer.valueOf(Configuracion.propiedades.getProperty("indiceColaborativo")));
			}
		}
		tray.setConfiguracionTray();		//se aplica la configuracin de tray
		if (Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion"))==false){
			tray.rbMenuItemColaborativo.setEnabled(false);
			tray.submenuColaborativo.setEnabled(false);
		}

		}		
	}//creaTray
	
	public boolean valorarTermino(int valor1 , int valor2){
		if (busqueda!=null){	
			String numter = (String) busqueda.getNumTermino(valor2);
			String tipo = String.valueOf( valor1 );
			valora = new Valoracion(numter,tipo ,conexion);
			valora.valorarTermino();
			
			return valora.isValorado();
			
		}
		
		return false;
		
	}//valorarTermino
	
	public void identificarUsuario(String user , String  pass){
		
		if (conexion.isConectado()){	
		
				UserRegis = new Usuario(user,pass,controlador,conexion);
				if ( UserRegis.identificarse() ){
					config.guardarconfiguracion();
					
					controlador.panelInicial.panelPestanas.pestana4.panelRegistrar.setVisible(false);
					controlador.panelInicial.panelPestanas.pestana4.panelAnadir.setVisible(true);

				}else{			
					System.out.println("No ha identificado");
				}
			}else{
				System.out.println("No hay conexion");
			}
			
		}//identificarUsuario
	
	public boolean anadirTermino(String radio, int indiceDesplegable){
		String wtabla = "";
		boolean inserta = false;
		wtabla = String.valueOf(config.arrayWikiInstall.get( indiceDesplegable));	
		inserta =  UserRegis.anadirTermino(wtabla,radio);	
		
		return inserta;
			
	}
		
		
	public Termino buscarTermino(String termino, Boolean porClipboard){
		
		Termino term;
		String dicColabSeleccionado;
		
		busqueda = new Busqueda();
		
		if (porClipboard){
			
			//Creamos el objeto clipboard solo cuando lo necesitamos
			if (clipboard == null){
				clipboard = new PortaPapeles();
			}
			//Recupero del ClipBoard la palabra
			termino = clipboard.getClipboardContents();
			//Escribo la palabra a buscar
			p1.campoTextoBusqueda.setText(termino);
			
		}
	
		p1.etiquetaMensaje.setText("");
		
		if (Configuracion.propiedades.getProperty("tipoDic").equals("Colaborativo") && conexion.isConectado() ){

			dicColabSeleccionado = String.valueOf(config.arrayWikiInstall.get(Integer.valueOf(Configuracion.propiedades.getProperty("indiceColaborativo"))));

			
			//Realizo la busqueda en el diccionario Colaborativo
			term = busqueda.traducirColaborativo(termino,dicColabSeleccionado,conexion);
			
		
			//Elimino los valores del desplegable
			p1.desplegableValorarNum.removeAllItems();
			
			//Aado los terminos a valorar en el desplegable
			for (int i = 0; i < busqueda.getNumeroPalabras(); i++) {
				p1.desplegableValorarNum.addItem(String.valueOf(i+1));
			}
			return term;
			
		}else{

			term= busqueda.traducirLocal(termino);
			return term;
		}
				
	}//buscarTermino 
	
	public void accionCambiarDiccionario(){
		
		String contenido = "";
		contenido = p1.campoTextoBusqueda.getText();

		if (Configuracion.propiedades.getProperty("tipoDic").equals("Colaborativo")){
			
			//cambiar leyenda de la interfaz
			p1.etiquetaDiccionario.setText(String.valueOf(config.arrayWikiInstall.get(Integer.valueOf(Configuracion.propiedades.getProperty("indiceColaborativo")))));
			
		}
		if (!contenido.equals("")){		
				//Buscar
				buscarTermino(contenido,false);
			
		}
		creaTray();
	}//accionCambiarDiccionario
	
	public void accionCajaConexion(){
		
		if (Boolean.parseBoolean(Configuracion.propiedades.getProperty("dispConexion"))==false){
			p2.etiquetaDicWiki.setForeground(Color.lightGray);
			p2.desplegableDicWiki.setEnabled(false);
			p1.desplegableTipoDic.removeItem(Configuracion.messages.getString("combo_colaborativo"));
			p1.etiquetaMensaje.setText("Cooltran");
			
		}else{
			//conecta con la base de datos si no estaba conectado
			
			if(!conexion.isConectado()){
				p1.etiquetaMensaje.setText(Configuracion.messages.getString("msj_conectando"));
				conexion = new Conexion();		//se crea la conexin con la base de datos
				try{
					conexion.conectar();
					if (conexion.isConectado()){

						//creamos los colaborativos
						
						config.cargarColaborativo(conexion);	
						UserRegis = config.aplicarConfiguracionColaborativo(controlador,conexion);
						p1.desplegableTipoDic.addItem(Configuracion.messages.getString("combo_colaborativo"));
						config.cambiaTipoDic("Colaborativo");
						p1.desplegableTipoDic.setSelectedItem(Configuracion.messages.getString("combo_colaborativo"));
						p1.etiquetaDiccionario.setText(String.valueOf(config.arrayWikiInstall.get(Integer.valueOf(Configuracion.propiedades.getProperty("indiceColaborativo")))));
						p1.etiquetaMensaje.setText(Configuracion.messages.getString("msj_conectado"));
						p1.scrollPaneBusqueda.panelTextoScroll.setText("");
				
					}
				 }catch(Exception conexion){
			    	p1.etiquetaMensaje.setText(Configuracion.messages.getString("msj_errorconexion"));
			     }
			}else{ //si ya estaba conectado solo tiene q aadir lo que quit
				p1.desplegableTipoDic.addItem(Configuracion.messages.getString("combo_colaborativo"));
				config.cambiaTipoDic("Colaborativo");
				p1.desplegableTipoDic.setSelectedItem(Configuracion.messages.getString("combo_colaborativo"));
				p1.etiquetaDiccionario.setText(String.valueOf(config.arrayWikiInstall.get(Integer.valueOf(Configuracion.propiedades.getProperty("indiceColaborativo")))));
				p1.etiquetaMensaje.setText(Configuracion.messages.getString("msj_conectado"));
			}
			//----------
			p2.etiquetaDicWiki.setForeground(Color.white);
			p2.desplegableDicWiki.setEnabled(true);
		}
		//cambia tb en tray (si esta en windows claro)
				creaTray();
				
	}//accionCajaConexion
	
	public void cambiarColorInterfaz(){
		
		controlador.cambiarColorInterfaz();
	}
	
	public void cambiarIdiomaInterfaz(){
		
		controlador.cambiarIdiomaInterfaz();
	}
	
	
	/*******************************************************************
	 *						        MAIN
	 *********************************************************************/	
	
	public static void main(String[] args) {
		
		new Aplicacion();
		
	}
	
}//aplicacion


