 /* CoolTran, traductor de trminos.
 * 
 * Copyright (C) 2007
 *
 * Authors: Javier Garca Palacios <jgarcia1709@gmail.com>
 *          Diego Sevillano de Miguel <sevas85@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 */


import java.awt.Color;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.ArrayList;
import java.util.Locale;
import java.util.Properties;
import java.util.ResourceBundle;



public class Configuracion {
	
	String[] arrayCadIdioma = {"Espaol","English","Deutsch","Franaise","Portugus"};
	String[] arrayCadDiccInstall = null;
	ArrayList<String> arrayWikiInstall = null;
	//ArrayList<String> arrayWikiTabla = null;
    static ResourceBundle messages;
    Locale currentLocale = null;
    static Properties propiedades = null;
    static DiccionarioLocal diccionarioLocalTraduc = null;
    String cadArchivoOrigen = null;   
    

	public Configuracion () { //carga la configuracion de la aplicacion del fichero
		
		cadArchivoOrigen="config/Configuracion.properties";  

		 FileInputStream f;
		
		try {
			
			f =  new FileInputStream(cadArchivoOrigen);
			propiedades = new Properties();
			propiedades.load(f);
			f.close();
			
		} catch (IOException e) {
			System.out.println("ERROR CARGANDO EL FICHERO CONFIGURACION");
		}			
	
		Locale []  LocalesSoportados = {
			    new Locale("es","ES"),
			    new Locale("en","EN"),
			    new Locale("de","DE"),
			    new Locale("fr","FR"),
			    new Locale("pt","PT")
		};
		
		currentLocale = LocalesSoportados[Integer.valueOf(propiedades.getProperty("idiDefault"))];	
		messages = ResourceBundle.getBundle("lang/MessagesBundle",currentLocale);
		
		//por defecto -1 carga el de configuracion
		cambiarDiccionario("-1");
		
		//Guardo el SO
		cambiaSO(System.getProperty("os.name"));
		
	}//configuracion
	
	
	public  void guardarconfiguracion(){ //guarda la configuracion de la aplicacion al fichero
		
		FileOutputStream out;
		try {
			out = new FileOutputStream(cadArchivoOrigen);
			propiedades.store(out, "---Grabacion de Configuracin---");
			out.close();
			
		} catch (FileNotFoundException e) {
			System.out.println("ERROR BUSCANDO EL FICHERO");		
		} catch (IOException e) {
			System.out.println("ERROR GUARDANDO EL FICHERO");	
		}
		
	}//guardarConfiguracion
	
	public void cambiaridioma (String idioma){
		Locale []  LocalesSoportados = {
				 new Locale("es","ES"),
				 new Locale("en","EN"),
				 new Locale("de","DE"),
				 new Locale("fr","FR"),
				 new Locale("pt","PT")
		};
		
		currentLocale = LocalesSoportados[Integer.valueOf(idioma)];	
		messages = ResourceBundle.getBundle("lang/MessagesBundle",currentLocale);
		propiedades.setProperty("idiDefault", idioma);
		guardarconfiguracion();

	}//cambiaridioma
	
	
	public void cambiarDiccionario(String diccionario) {
		
		FileInputStream f = null;
	//	FileInputStream dicSoportados[] = null;
		
		if (!diccionario.equals("-1")){
			propiedades.setProperty("dicLocDefault", diccionario);
			guardarconfiguracion();
		}
		
		localizarDiccionarios(); //busca diccionarios sistema
		
		try{

			f=new FileInputStream("diccionarios/"+propiedades.getProperty("dicLocDefault")+".properties");
			diccionarioLocalTraduc = new DiccionarioLocal();
			diccionarioLocalTraduc.cargar(f);
			
			
			//falta cerrar punteros a ficheros
		
		}catch(IOException e){	
			System.out.println("HEMOS CAMBIADO EL TRADUCTOR");
		}
	
	}//cambiarDiccionario
	
	
	
	public void localizarDiccionarios( ) {
		
		File fichero=new File("diccionarios");
		
		String[] listaArchivos=fichero.list();
		int nDic = 0;
		int cont = 0;
		
		//contamos el numero de diccionario correctos
		for(int i=0; i<listaArchivos.length; i++){
			if (listaArchivos[i].endsWith(".properties")) {
				nDic++;
			}
		}
		
		arrayCadDiccInstall = new String[nDic];
		
		for(int i=0; i<listaArchivos.length; i++){
			if (listaArchivos[i].endsWith(".properties")) {
				arrayCadDiccInstall[cont]="diccionarios/"  + listaArchivos[i];
				//System.out.println(dicc_install[cont]);
				cont++;
			}
		}

	}//localizarDiccionarios
	
	
	public void cargarColaborativo(Conexion conexion){
			
		Connection con = null;
		String query = "";
		Statement stmt = null; 
		ResultSet res = null;

		try{
		
		con = conexion.con;
		query ="select nombre from diccionarios";
	
		stmt =(Statement) con.createStatement();	
		res = (ResultSet) stmt.executeQuery(query);
			
		arrayWikiInstall = new ArrayList<String>();
		//arrayWikiTabla = new ArrayList<String>();
			
		while (res.next()){		
			arrayWikiInstall.add(res.getString(1));
			//arrayWikiTabla.add(res.getString(2));		
		}
						
		} catch (SQLException e) {
			System.out.println("Error consultando los diccionarios colaborativos");
			e.printStackTrace();
		}

	}//cargarColaborativo

	public void cambiaTipoDic(String tipo){
		propiedades.setProperty("tipoDic", tipo);
		guardarconfiguracion();
	}//cambiaTipoDic
	
	
	public void cambiaDicColab(String tipo){
		propiedades.setProperty("dicColDefault", tipo);
		guardarconfiguracion();
	}//cambiaTipoDic
	
	public void cambiaIndiceColab(String indice){
		propiedades.setProperty("indiceColaborativo", indice);
		guardarconfiguracion();
	}//cambiaIndiceDic
	
	public void cambiaConexion(String conexion){
		propiedades.setProperty("dispConexion", conexion);
		guardarconfiguracion();
	}//cambiaConexion
	
	public void cambiaTeclas(String tecla, String estado){
		propiedades.setProperty(tecla, estado);
		guardarconfiguracion();
	}//cambiaTeclas
	
	public void cambiaSplash(String splash){
		propiedades.setProperty("splash", splash);
		guardarconfiguracion();
	}//cambiaSplash
	
	public void cambiaSO(String SO){
		propiedades.setProperty("SO", SO);
		guardarconfiguracion();
	}//cambiaSplash
	
	public void cambiaBaseDatos(String fecha,String usuario, String password, String url){
		propiedades.setProperty("fechabd", fecha);
		propiedades.setProperty("loginbd", usuario);
		propiedades.setProperty("passbd", password);
		propiedades.setProperty("urlbd", url);
		guardarconfiguracion();
	}//cambiaSplash
		
	
	public void aplicarConfiguracion( Ventana ventana){
		
		
		for (int i = 0; i < arrayCadDiccInstall.length; i++) {	
			
			ventana.panelInicial.panelPestanas.pestana2.desplegableDicLocal.addItem(arrayCadDiccInstall[i].substring(13,20));
		}	
					
		for (int i = 0; i < arrayCadIdioma.length; i++) {
			ventana.panelInicial.panelPestanas.pestana3.desplegableIdioma.addItem(arrayCadIdioma[i]);
		}
		
		for (int i = 1; i < 4; i++) {
	
		ventana.panelInicial.panelPestanas.pestana1.desplegableValorarValor.addItem(messages.getString("l_valorar_desp_"+i));
		}


		ventana.panelInicial.panelPestanas.pestana1.desplegableTipoDic.setSelectedIndex(0);
		ventana.panelInicial.panelPestanas.pestana1.etiquetaValorar.setVisible(false);
		ventana.panelInicial.panelPestanas.pestana1.etiquetaValorar2.setVisible(false);
		ventana.panelInicial.panelPestanas.pestana1.desplegableValorarValor.setVisible(false);
		ventana.panelInicial.panelPestanas.pestana1.desplegableValorarNum.setVisible(false);

		ventana.panelInicial.panelPestanas.pestana3.cajaValidarConexion.setSelected(Boolean.parseBoolean(propiedades.getProperty("dispConexion")));
		ventana.panelInicial.panelPestanas.pestana3.desplegableIdioma.setSelectedIndex(Integer.valueOf(propiedades.getProperty("idiDefault")));
		ventana.panelInicial.panelPestanas.pestana2.desplegableDicLocal.setSelectedItem(String.valueOf(propiedades.getProperty("dicLocDefault")));


		
		ventana.panelInicial.panelPestanas.pestana3.cajaValidarSplash.setSelected(Boolean.parseBoolean(propiedades.getProperty("splash")));
		
		
		
		//Parametros relacionados con la conexion por defecto desactivados
		
			ventana.panelInicial.panelPestanas.pestana2.etiquetaDicWiki.setForeground(Color.lightGray);
			ventana.panelInicial.panelPestanas.pestana2.desplegableDicWiki.setEnabled(false);
			ventana.panelInicial.panelPestanas.pestana1.desplegableTipoDic.removeItem(messages.getString("combo_colaborativo"));
			ventana.panelInicial.panelPestanas.pestana1.etiquetaValorar.setVisible(false);
			ventana.panelInicial.panelPestanas.pestana1.etiquetaValorar2.setVisible(false);
			ventana.panelInicial.panelPestanas.pestana1.desplegableValorarValor.setVisible(false);
			ventana.panelInicial.panelPestanas.pestana1.desplegableValorarNum.setVisible(false);
			
			//registrar
			ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.botonRegistrar.setEnabled(false);
			ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.campoContrasenaReg.setEnabled(false);
			ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.campoTextoUsuario.setEnabled(false);
			ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.etiquetaUsuario.setEnabled(false);
			ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.etiquetaPassword.setEnabled(false);
		//}
			
		
		
	}//aplicarConfiguracion
	
	public Usuario aplicarConfiguracionColaborativo(Ventana ventana, Conexion conexion){
		
		Usuario  UserRegis  = null;
		String wiki =  String.valueOf(propiedades.getProperty("dicColDefault"));
		
		//cargamos los nombres en la aplicacion de los diccionarios colaborativos: "wiki ESP-ENG"
		
		for (int i = 0; i < arrayWikiInstall.size(); i++) {

			ventana.panelInicial.panelPestanas.pestana2.desplegableDicWiki.addItem(arrayWikiInstall.get(i));
			ventana.panelInicial.panelPestanas.pestana4.panelAnadir.desplegableDicWiki.addItem(arrayWikiInstall.get(i));

		}			
		cambiaDicColab(wiki);

		ventana.panelInicial.panelPestanas.pestana2.desplegableDicWiki.setSelectedItem(String.valueOf(propiedades.getProperty("dicColDefault")));
		
		//Aplicamos la visibilidad de los elementos del colaborativo
		if (Boolean.parseBoolean(propiedades.getProperty("dispConexion"))==true){

				ventana.panelInicial.panelPestanas.pestana1.etiquetaMensaje.setText(Configuracion.messages.getString("msj_conectado"));
				ventana.panelInicial.panelPestanas.pestana1.scrollPaneBusqueda.panelTextoScroll.setText("");
							
				ventana.panelInicial.panelPestanas.pestana2.etiquetaDicWiki.setForeground(Color.white);
				ventana.panelInicial.panelPestanas.pestana2.desplegableDicWiki.setEnabled(true);
				ventana.panelInicial.panelPestanas.pestana1.desplegableTipoDic.addItem(Configuracion.messages.getString("combo_colaborativo"));

				
				//activo registrar
				ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.botonRegistrar.setEnabled(true);
				ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.campoContrasenaReg.setEnabled(true);
				ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.campoTextoUsuario.setEnabled(true);
				ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.etiquetaUsuario.setEnabled(true);
				ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.etiquetaPassword.setEnabled(true);
				
				if ((propiedades.getProperty("tipoDic")).equals("Colaborativo")){
					ventana.panelInicial.panelPestanas.pestana1.etiquetaValorar.setVisible(true);
					ventana.panelInicial.panelPestanas.pestana1.etiquetaValorar2.setVisible(true);
					ventana.panelInicial.panelPestanas.pestana1.desplegableValorarValor.setVisible(true);
					ventana.panelInicial.panelPestanas.pestana1.desplegableValorarNum.setVisible(true);				
					ventana.panelInicial.panelPestanas.pestana1.desplegableTipoDic.setSelectedItem(Configuracion.messages.getString("combo_colaborativo"));
					ventana.panelInicial.panelPestanas.pestana1.etiquetaDiccionario.setText(String.valueOf(arrayWikiInstall.get(Integer.valueOf(propiedades.getProperty("indiceColaborativo")))));
				}
		}
		
		
	     //CARGA DE USUARIO
	    
	     if (Configuracion.propiedades.containsKey("usuario") && Configuracion.propiedades.containsKey("password")){
	             
	                 UserRegis = new Usuario(Configuracion.propiedades.getProperty("usuario"),Configuracion.propiedades.getProperty("password"),ventana,conexion);
	                 if ( UserRegis.identificarse() ){
	                         ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.setVisible(false);
	                         ventana.panelInicial.panelPestanas.pestana4.panelAnadir.setVisible(true);
	                       
	                        return  UserRegis;
	                 }else{

	                 }      
	     }else{
	    	 ventana.panelInicial.panelPestanas.pestana4.panelRegistrar.etiquetaMensajeReg.setText(Configuracion.messages.getString("msj_primeravez"));
	     }
	     return null;
	    	   
	}
	
	
} 


